@@ -11,6 +11,8 @@ use ash::{
     vk,
 };
 
+use super::conv;
+
 unsafe extern "system" fn debug_utils_messenger_callback(
     message_severity: vk::DebugUtilsMessageSeverityFlagsEXT,
     message_type: vk::DebugUtilsMessageTypeFlagsEXT,
@@ -598,10 +600,33 @@ impl crate::Instance<super::Api> for super::Instance {
             }
         };
 
-        raw_devices
+        let mut exposed_adapters = raw_devices
             .into_iter()
             .flat_map(|device| self.expose_adapter(device))
-            .collect()
+            .collect::<Vec<_>>();
+
+        // detect if it's an Intel + NVidia configuration
+        if cfg!(target_os = "linux") {
+            use crate::auxil::db;
+            let has_nvidia_dgpu = exposed_adapters.iter().any(|exposed| {
+                exposed.info.device_type == wgt::DeviceType::DiscreteGpu
+                    && exposed.info.vendor == db::nvidia::VENDOR as usize
+            });
+            if has_nvidia_dgpu {
+                for exposed in exposed_adapters.iter_mut() {
+                    if exposed.info.device_type == wgt::DeviceType::IntegratedGpu
+                        && exposed.info.vendor == db::intel::VENDOR as usize
+                    {
+                        // See https://gitlab.freedesktop.org/mesa/mesa/-/issues/4688
+                        log::warn!("Disabling presentation on '{}' (id {:?}) because of an Nvidia dGPU (on Linux)",
+                            exposed.info.name, exposed.adapter.raw);
+                        exposed.adapter.private_caps.can_present = false;
+                    }
+                }
+            }
+        }
+
+        exposed_adapters
     }
 }
 
@@ -681,6 +706,10 @@ impl crate::Surface<super::Api> for super::Surface {
                 aspects: crate::FormatAspects::COLOR,
                 format_info: sc.config.format.describe(),
                 raw_flags: vk::ImageCreateFlags::empty(),
+                copy_size: conv::map_extent_to_copy_size(
+                    &sc.config.extent,
+                    wgt::TextureDimension::D2,
+                ),
             },
         };
         Ok(Some(crate::AcquiredSurfaceTexture {
