@@ -158,6 +158,8 @@ struct PrivateCapabilities {
     timeline_semaphores: bool,
     texture_d24: bool,
     texture_d24_s8: bool,
+    /// Ability to present contents to any screen. Only needed to work around broken platform configurations.
+    can_present: bool,
     non_coherent_map_mask: wgt::BufferAddress,
 }
 
@@ -219,7 +221,7 @@ struct DeviceShared {
     instance: Arc<InstanceShared>,
     extension_fns: DeviceExtensionFunctions,
     vendor_id: u32,
-    _timestamp_period: f32,
+    timestamp_period: f32,
     downlevel_flags: wgt::DownlevelFlags,
     private_caps: PrivateCapabilities,
     render_passes: Mutex<fxhash::FxHashMap<RenderPassKey, vk::RenderPass>>,
@@ -265,6 +267,7 @@ pub struct Texture {
     aspects: crate::FormatAspects,
     format_info: wgt::TextureFormatInfo,
     raw_flags: vk::ImageCreateFlags,
+    copy_size: crate::CopyExtent,
 }
 
 #[derive(Debug)]
@@ -538,6 +541,10 @@ impl crate::Queue<Api> for Queue {
         }
         Ok(())
     }
+
+    unsafe fn get_timestamp_period(&self) -> f32 {
+        self.device.timestamp_period
+    }
 }
 
 impl From<vk::Result> for crate::DeviceError {
